==> dart-sass-maven-plugin-1.3.1-sources.jar: com/github/cleydyr/dart/system/io/factory/DefaultDartSassExecutableExtractorFactory.java <==
package com.github.cleydyr.dart.system.io.factory;

import com.github.cleydyr.dart.release.DartSassReleaseParameter;
import com.github.cleydyr.dart.system.OSDetector;
import com.github.cleydyr.dart.system.io.ApacheFluidHttpClientReleaseDownloader;
import com.github.cleydyr.dart.system.io.DartSassExecutableExtractor;
import com.github.cleydyr.dart.system.io.ExecutableResourcesProvider;
import com.github.cleydyr.dart.system.io.PosixDartSassSnapshotExecutableExtractor;
import com.github.cleydyr.dart.system.io.TarFilesystemExecutableResourcesProvider;
import com.github.cleydyr.dart.system.io.WindowsDartSassExecutableExtractor;
import com.github.cleydyr.dart.system.io.ZipFilesystemExecutableResourcesProvider;
import com.github.cleydyr.dart.system.io.exception.DartSassExecutableExtractorException;
import java.io.File;
import java.net.URISyntaxException;
import java.net.URL;
import javax.inject.Named;
import javax.inject.Singleton;

@Named
@Singleton
public class DefaultDartSassExecutableExtractorFactory implements DartSassExecutableExtractorFactory {
    @Override
    public DartSassExecutableExtractor getDartSassExecutableExtractor(
            DartSassReleaseParameter dartSassReleaseParameter, File cachedFileDirectory, URL proxyHost) {
        try {
            if (OSDetector.isWindows()) {
                ExecutableResourcesProvider executableResourcesProvider;
                executableResourcesProvider = new ZipFilesystemExecutableResourcesProvider(
                        cachedFileDirectory, new ApacheFluidHttpClientReleaseDownloader(proxyHost));

                return new WindowsDartSassExecutableExtractor(dartSassReleaseParameter, executableResourcesProvider);
            }

            ExecutableResourcesProvider executableResourcesProvider = new TarFilesystemExecutableResourcesProvider(
                    cachedFileDirectory, new ApacheFluidHttpClientReleaseDownloader(proxyHost));

            return new PosixDartSassSnapshotExecutableExtractor(dartSassReleaseParameter, executableResourcesProvider);
        } catch (URISyntaxException e) {
            throw new DartSassExecutableExtractorException("Error while creating DartSassExecutableExtractor", e);
        }
    }
}

==> dart-sass-maven-plugin-1.4.0-sources.jar: com/github/cleydyr/dart/system/io/factory/DefaultDartSassExecutableExtractorFactory.java <==
package com.github.cleydyr.dart.system.io.factory;

import com.github.cleydyr.dart.release.DartSassReleaseParameter;
import com.github.cleydyr.dart.system.OSDetector;
import com.github.cleydyr.dart.system.io.ApacheFluidHttpClientReleaseDownloader;
import com.github.cleydyr.dart.system.io.DartSassExecutableExtractor;
import com.github.cleydyr.dart.system.io.ExecutableResourcesProvider;
import com.github.cleydyr.dart.system.io.PosixDartSassSnapshotExecutableExtractor;
import com.github.cleydyr.dart.system.io.TarFilesystemExecutableResourcesProvider;
import com.github.cleydyr.dart.system.io.WindowsDartSassExecutableExtractor;
import com.github.cleydyr.dart.system.io.ZipFilesystemExecutableResourcesProvider;
import com.github.cleydyr.dart.system.io.exception.DartSassExecutableExtractorException;
import java.io.File;
import java.net.MalformedURLException;
import java.net.URISyntaxException;
import javax.inject.Named;
import javax.inject.Singleton;
import org.apache.maven.settings.Proxy;

@Named
@Singleton
public class DefaultDartSassExecutableExtractorFactory implements DartSassExecutableExtractorFactory {

    @Override
    public DartSassExecutableExtractor getDartSassExecutableExtractor(
            DartSassReleaseParameter dartSassReleaseParameter, File cachedFileDirectory, Proxy proxy) {
        try {
            if (OSDetector.isWindows()) {
                ExecutableResourcesProvider executableResourcesProvider;
                executableResourcesProvider = new ZipFilesystemExecutableResourcesProvider(
                        cachedFileDirectory, new ApacheFluidHttpClientReleaseDownloader(proxy));

                return new WindowsDartSassExecutableExtractor(dartSassReleaseParameter, executableResourcesProvider);
            }

            ExecutableResourcesProvider executableResourcesProvider = new TarFilesystemExecutableResourcesProvider(
                    cachedFileDirectory, new ApacheFluidHttpClientReleaseDownloader(proxy));

            return new PosixDartSassSnapshotExecutableExtractor(dartSassReleaseParameter, executableResourcesProvider);
        } catch (URISyntaxException | MalformedURLException e) {
            throw new DartSassExecutableExtractorException("Error while creating DartSassExecutableExtractor", e);
        }
    }
}
